package TiVo::Show;

use strict;
use Carp;
use TiVo::Config;
use File::Path;

our $VERSION =
    (split / /, q$Id: Show.pm,v 1.3 2001/12/05 21:46:38 grant Exp $)[2];

sub new {
    my $class = shift;
    my $self = {};
    bless $self, $class;
    return $self;
}

sub get {
    my $self = shift;
    my $key = shift;
    return $self->{data}->{$key};
}

sub set {
    my $self = shift;
    my ($key, $value) = @_;
    $self->{data}->{$key} = $value;
    $self->{changed}++;
    return $value;
}

# get or set the short way
AUTOLOAD {
    my $self = shift;
    our $AUTOLOAD;
    my $key = $AUTOLOAD;
    $key =~ s/.*:://;
    my $value = shift;
    if (defined $value) {
        $self->set($key, $value);
    }
    return $self->get($key);
}

sub save {
    my $self = shift;
    my $conf = TiVo::Config->new;
    my $path = join('/', $conf->guidedir, 'shows', $self->day, $self->station);
    mkpath($path);
    my $time = $self->time;
    open(my $file, ">$path/$time") or die "failed open for write ($!)";
    for my $key (sort keys %{$self->{data}}) {
        my $value = $self->{data}->{$key};
        print $file "$key = $value\n";
    }
    close($file) or die "failed close ($!)";
}

sub load {
    my $self = shift;
    unless (map(defined, $self->day, $self->station, $self->time)) {
        croak "Show load needs day, station, and time.";
    }
    my $conf = TiVo::Config->new;
    my $path = join(
                    '/',
                    $conf->guidedir,
                    'shows',
                    $self->day,
                    $self->station,
                    $self->time,
                   );
    open(my $file, $path) or die "failed open of $path ($!)";
    while (<$file>) {
        next if /^\s*\#/;
        next if /^\s*$/;
        chomp;
        my ($key, $value) = split /\s*=\s*/;
        $self->set($key, $value);
    }
    close($file) or die "failed close of $path ($!)";
}

1;
