package TiVo::Slice::Number;

use strict;

our $VERSION =
    (split / /, q$Id: Number.pm,v 1.3 2002/03/16 04:51:02 grant Exp $)[2];

# takes an integer, and constructs a TiVo-encoded number
sub new {
    my $class = shift;
    my $number = shift;

    my $self = {};
    bless($self, $class);

    # 0-63                 1 byte   0x3F       00, then 6 bits
    # 64-4095              2 bytes  0x0FFF     10, then 12 bits (why not 14?)
    # 4096-1048575         3 bytes  0x0FFFFF   1100, then 20 bits
    # 1048576-268435455    4 bytes  0x0FFFFFFF 1110, then 28 bits
    # 268435456-4294967295 5 bytes  0xFFFFFFFF 1111, then 36 bits (but 32 used)

    my $tivonumber;

    # C is char (1 byte)
    # n is network short (2 bytes)
    # N is network long (4 bytes)

    # too big
    if ($number >= 2**32) {
        die "$number is too big";
    }
    # 5 bytes
    elsif ($number >= 2**28) {
        $tivonumber = pack("C N", 0xF0, $number);
    }
    # 4 bytes
    elsif ($number >= 2**20) {
        $tivonumber = pack("N", $number | 0xE0000000);
    }
    # 3 bytes
    elsif ($number >= 2**12) {
        $tivonumber = pack("C n", (($number >> 16) | 0xC0), $number);
    }
    # 2 bytes
    elsif ($number >= 2**6) {
        $tivonumber = pack("n", $number | 0x8000);
    }
    # 1 byte
    else {
        $tivonumber = pack("C", $number);
    }

    $self->{number} = $number;
    $self->{tivonumber} = $tivonumber;
    
    return $self;
}

sub tivonumber {
    my $self = shift;
    return $self->{tivonumber};
}

sub number {
    my $self = shift;
    return $self->{number};
}

1;
